import{a as s}from"./chunk-MNHOAW4R.js";import"./chunk-ZMBQGVIF.js";import{a as i}from"./chunk-WVYKIHVG.js";import"./chunk-5DJUZA4F.js";import"./chunk-YICKNY6Y.js";import"./chunk-R7CM4BQN.js";import"./chunk-SNGMH3JW.js";import"./chunk-EXFMYL6U.js";import"./chunk-WSHCWW4Q.js";import"./chunk-ZNREFWKG.js";import"./chunk-FZLE27CN.js";import"./chunk-CD5RYVNW.js";import"./chunk-JFI5BOLY.js";import"./chunk-IRNO36C3.js";import"./chunk-43RBMH4Y.js";import"./chunk-K2JFJOPP.js";import"./chunk-CCQNES6G.js";import"./chunk-FK4OKHO7.js";import{O as n}from"./chunk-NLCJ5AKJ.js";import{b as a}from"./chunk-3CEAP2V5.js";import{a as r}from"./chunk-6LQNQPBM.js";import"./chunk-OOJM4CTU.js";var g={parse:r(async e=>{let t=await s("info",e);a.debug(t)},"parse")},m={version:"11.17.0"},v=r(()=>m.version,"getVersion"),d={getVersion:v},f=r((e,t,p)=>{a.debug(`rendering info diagram
`+e);let o=i(t);n(o,100,400,!0),o.append("g").append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${p}`)},"draw"),c={draw:f},w={parser:g,db:d,renderer:c};export{w as diagram};
